==> gutenbergr_0.1.tar.gz: gutenbergr/inst/doc/intro.R <==
## ----frankenstein--------------------------------------------------------
library(dplyr)
library(gutenbergr)

frankenstein <- gutenberg_download(84)

frankenstein

## ----frankenstein_dracula------------------------------------------------
frankenstein_dracula <- gutenberg_download(c(84, 345), meta_fields = "title")

frankenstein_dracula

## ------------------------------------------------------------------------
frankenstein_dracula %>%
  count(title)

## ------------------------------------------------------------------------
gutenberg_metadata

## ------------------------------------------------------------------------
gutenberg_metadata %>%
  filter(title == "Wuthering Heights")

## ------------------------------------------------------------------------
gutenberg_works()

## ------------------------------------------------------------------------
gutenberg_works(author == "Austen, Jane")

## ------------------------------------------------------------------------
gutenberg_subjects

## ------------------------------------------------------------------------
gutenberg_subjects %>%
  filter(subject == "Horror tales")

gutenberg_subjects %>%
  filter(grepl("Holmes, Sherlock", subject))

## ------------------------------------------------------------------------
gutenberg_authors

## ------------------------------------------------------------------------
library(tidytext)

words <- frankenstein_dracula %>%
  unnest_tokens(word, text)

words

word_counts <- words %>%
  anti_join(stop_words, by = "word") %>%
  count(title, word, sort = TRUE)

word_counts

==> gutenbergr_0.1.5.tar.gz: gutenbergr/inst/doc/intro.R <==
## ----echo = FALSE--------------------------------------------------------
knitr::opts_chunk$set(message = FALSE, warning = FALSE)

## ------------------------------------------------------------------------
library(gutenbergr)
gutenberg_metadata

## ------------------------------------------------------------------------
library(dplyr)

gutenberg_metadata %>%
  filter(title == "Wuthering Heights")

## ------------------------------------------------------------------------
gutenberg_works()

## ------------------------------------------------------------------------
gutenberg_works(author == "Austen, Jane")

# or with a regular expression

library(stringr)
gutenberg_works(str_detect(author, "Austen"))

## ------------------------------------------------------------------------
wuthering_heights <- gutenberg_download(768)

wuthering_heights

## ------------------------------------------------------------------------
books <- gutenberg_download(c(768, 1260), meta_fields = "title")

books

## ------------------------------------------------------------------------
books %>%
  count(title)

## ------------------------------------------------------------------------
gutenberg_subjects

## ------------------------------------------------------------------------
gutenberg_subjects %>%
  filter(subject == "Detective and mystery stories")

gutenberg_subjects %>%
  filter(grepl("Holmes, Sherlock", subject))

## ------------------------------------------------------------------------
gutenberg_authors

## ------------------------------------------------------------------------
library(tidytext)

words <- books %>%
  unnest_tokens(word, text)

words

word_counts <- words %>%
  anti_join(stop_words, by = "word") %>%
  count(title, word, sort = TRUE)

word_counts
